A call to this function will source and compile the latest version of the southern hemisphere seabird risk assessment model. The model is written in stan and can be run using the sampling function from the rstan package.
Usage
sefra(
data,
write_to = NULL,
read_from = NULL,
likelihood = c("cumulative", "empirical")[1]
)Arguments
- data
A list of data inputs. See
sefraData.- write_to
Write model code to file.
- read_from
Read model code from file.
- likelihood
Fit to either the
cumulativeorempiricalcaptures.